Coverage report

# Coverage report: 100%

Hot-keys on this page

n s m x b p c change column sorting

Module | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | ---
Total | 1839 | 0 | 0 | 701 | 0 | 100%
lupyne/__init__ | 1 | 0 | 0 | 0 | 0 | 100%
lupyne/client | 178 | 0 | 0 | 48 | 0 | 100%
lupyne/engine/__init__ | 10 | 0 | 0 | 2 | 0 | 100%
lupyne/engine/documents | 241 | 0 | 0 | 90 | 0 | 100%
lupyne/engine/indexers | 515 | 0 | 0 | 198 | 0 | 100%
lupyne/engine/queries | 316 | 0 | 0 | 102 | 0 | 100%
lupyne/engine/spatial/__init__ | 82 | 0 | 0 | 32 | 0 | 100%
lupyne/server | 496 | 0 | 0 | 229 | 0 | 100%